@@ -1,4 +1,6 @@
 from .air_pls import AirPls
+from .ar_pls import ArPls
+from .constant_baseline_correction import ConstantBaselineCorrection
 from .cubic_spline_correction import CubicSplineCorrection
 from .linear_correction import LinearCorrection
 from .non_negative import NonNegative
