@@ -1,12 +1,46 @@
 import numpy as np
 from scipy.ndimage import convolve1d
-from sklearn.base import BaseEstimator, TransformerMixin
+from sklearn.base import BaseEstimator, TransformerMixin, OneToOneFeatureMixin
 from sklearn.utils.validation import check_is_fitted
 
 from chemotools.utils.check_inputs import check_input
 
 
-class NorrisWilliams(BaseEstimator, TransformerMixin):
+class NorrisWilliams(OneToOneFeatureMixin, BaseEstimator, TransformerMixin):
+    """
+    A transformer that calculates the Norris-Williams derivative of the input data.
+
+    Parameters
+    ----------
+    window_size : int, optional
+        The size of the window to use for the derivative calculation. Must be odd. Default is 5.
+
+    gap_size : int, optional
+        The size of the gap to use for the derivative calculation. Must be odd. Default is 3.
+
+    derivative_order : int, optional
+        The order of the derivative to calculate. Can be 1 or 2. Default is 1.
+
+    mode : str, optional
+        The mode to use for the derivative calculation. Can be "nearest", "constant", 
+        "reflect", "wrap", "mirror" or "interp". Default is "nearest".
+
+    Attributes
+    ----------
+    n_features_in_ : int
+        The number of features in the input data.
+
+    _is_fitted : bool
+        Whether the transformer has been fitted to data.
+
+    Methods
+    -------
+    fit(X, y=None)
+        Fit the transformer to the input data.
+
+    transform(X, y=0, copy=True)
+        Transform the input data by calculating the Norris-Williams derivative.
+    """
     def __init__(
         self,
         window_size: int = 5,
@@ -20,6 +54,22 @@ class NorrisWilliams(BaseEstimator, TransformerMixin):
         self.mode = mode
 
     def fit(self, X: np.ndarray, y=None) -> "NorrisWilliams":
+        """
+        Fit the transformer to the input data.
+
+        Parameters
+        ----------
+        X : np.ndarray of shape (n_samples, n_features)
+            The input data to fit the transformer to.
+
+        y : None
+            Ignored.
+
+        Returns
+        -------
+        self : NorrisWilliams
+            The fitted transformer.
+        """
         # Check that X is a 2D array and has only finite values
         X = check_input(X)
 
@@ -32,6 +82,22 @@ class NorrisWilliams(BaseEstimator, TransformerMixin):
         return self
 
     def transform(self, X: np.ndarray, y=None):
+        """
+        Transform the input data by calculating the Norris-Williams derivative.
+
+        Parameters
+        ----------
+        X : np.ndarray of shape (n_samples, n_features)
+            The input data to transform.
+
+        y : None
+            Ignored.
+
+        Returns
+        -------
+        X_ : np.ndarray of shape (n_samples, n_features)
+            The transformed data.
+        """
         # Check that the estimator is fitted
         check_is_fitted(self, "_is_fitted")
 
@@ -50,13 +116,15 @@ class NorrisWilliams(BaseEstimator, TransformerMixin):
                 X_[i] = derivative
             return X_.reshape(-1, 1) if X_.ndim == 1 else X_
 
-        if self.derivative_order == 1:
+        if self.derivative_order == 2:
             for i, x in enumerate(X_):
                 derivative = self._spectrum_second_derivative(x)
                 X_[i] = derivative
             return X_.reshape(-1, 1) if X_.ndim == 1 else X_
 
-        print("Derivative order must be either 1 or 2")
+        raise ValueError(
+            f"Expected derivative_order to be 1 or 2 but got {self.derivative_order}"
+        )
 
     def _smoothing_kernel(self):
         return np.ones(self.window_size) / self.window_size
