@@ -1,10 +1,30 @@
 from sklearn.utils.estimator_checks import check_estimator
 
-from chemotools.baseline import AirPls, CubicSplineCorrection, LinearCorrection, NonNegative, PolynomialCorrection, SubtractReference
+from chemotools.baseline import (
+    AirPls,
+    ArPls,
+    ConstantBaselineCorrection,
+    CubicSplineCorrection,
+    LinearCorrection,
+    NonNegative,
+    PolynomialCorrection,
+    SubtractReference,
+)
 from chemotools.derivative import NorrisWilliams, SavitzkyGolay
-from chemotools.scale import MinMaxScaler, LNormalize
-from chemotools.scatter import MultiplicativeScatterCorrection, StandardNormalVariate
-from chemotools.smooth import MeanFilter, MedianFilter, SavitzkyGolayFilter, WhittakerSmooth
+from chemotools.scale import IndexScaler, MinMaxScaler, NormScaler
+from chemotools.scatter import (
+    ExtendedMultiplicativeScatterCorrection,
+    MultiplicativeScatterCorrection,
+    RobustNormalVariate,
+    StandardNormalVariate,
+)
+from chemotools.smooth import (
+    MeanFilter,
+    MedianFilter,
+    SavitzkyGolayFilter,
+    WhittakerSmooth,
+)
+from chemotools.variable_selection import RangeCut
 
 from tests.fixtures import spectrum
 
@@ -16,6 +36,23 @@ def test_compliance_air_pls():
     # Act & Assert
     check_estimator(transformer)
 
+
+# ArPls
+def test_compliance_ar_pls():
+    # Arrange
+    transformer = ArPls()
+    # Act & Assert
+    check_estimator(transformer)
+
+
+# ConstantBaselineCorrection
+def test_compliance_constant_baseline_correction():
+    # Arrange
+    transformer = ConstantBaselineCorrection()
+    # Act & Assert
+    check_estimator(transformer)
+
+
 # CubicSplineCorrection
 def test_compliance_cubic_spline_correction():
     # Arrange
@@ -23,6 +60,22 @@ def test_compliance_cubic_spline_correction():
     # Act & Assert
     check_estimator(transformer)
 
+
+# ExtendedMultiplicativeScatterCorrection
+def test_compliance_extended_multiplicative_scatter_correction():
+    # Arrange
+    transformer = ExtendedMultiplicativeScatterCorrection()
+    # Act & Assert
+    check_estimator(transformer) 
+
+# IndexScaler
+def test_compliance_index_scaler():
+    # Arrange
+    transformer = IndexScaler()
+    # Act & Assert
+    check_estimator(transformer)
+
+
 # LinearCorrection
 def test_compliance_linear_correction():
     # Arrange
@@ -30,13 +83,15 @@ def test_compliance_linear_correction():
     # Act & Assert
     check_estimator(transformer)
 
+
 # LNormalize
 def test_compliance_l_norm():
     # Arrange
-    transformer = LNormalize()
+    transformer = NormScaler()
     # Act & Assert
     check_estimator(transformer)
 
+
 # MeanFilter
 def test_compliance_mean_filter():
     # Arrange
@@ -44,6 +99,7 @@ def test_compliance_mean_filter():
     # Act & Assert
     check_estimator(transformer)
 
+
 # MedianFilter
 def test_compliance_median_filter():
     # Arrange
@@ -51,6 +107,7 @@ def test_compliance_median_filter():
     # Act & Assert
     check_estimator(transformer)
 
+
 # MinMaxNormalize
 def test_compliance_min_max_norm():
     # Arrange
@@ -58,6 +115,7 @@ def test_compliance_min_max_norm():
     # Act & Assert
     check_estimator(transformer)
 
+
 # MultiplicativeScatterCorrection
 def test_compliance_multiplicative_scatter_correction():
     # Arrange
@@ -65,6 +123,7 @@ def test_compliance_multiplicative_scatter_correction():
     # Act & Assert
     check_estimator(transformer)
 
+
 # NonNegative
 def test_compliance_non_negative():
     # Arrange
@@ -72,6 +131,7 @@ def test_compliance_non_negative():
     # Act & Assert
     check_estimator(transformer)
 
+
 # NorrisWilliams
 def test_compliance_norris_williams():
     # Arrange
@@ -79,6 +139,15 @@ def test_compliance_norris_williams():
     # Act & Assert
     check_estimator(transformer)
 
+
+# NorrisWilliams
+def test_compliance_norris_williams_2():
+    # Arrange
+    transformer = NorrisWilliams(derivative_order=2)
+    # Act & Assert
+    check_estimator(transformer)
+
+
 # PolynomialCorrection
 def test_compliance_polynomial_correction():
     # Arrange
@@ -86,6 +155,7 @@ def test_compliance_polynomial_correction():
     # Act & Assert
     check_estimator(transformer)
 
+
 # SavitzkyGolay
 def test_compliance_savitzky_golay():
     # Arrange
@@ -93,6 +163,7 @@ def test_compliance_savitzky_golay():
     # Act & Assert
     check_estimator(transformer)
 
+
 # SavitzkyGolayFilter
 def test_compliance_savitzky_golay_filter():
     # Arrange
@@ -100,6 +171,7 @@ def test_compliance_savitzky_golay_filter():
     # Act & Assert
     check_estimator(transformer)
 
+
 # StandardNormalVariate
 def test_compliance_standard_normal_variate():
     # Arrange
@@ -107,6 +179,22 @@ def test_compliance_standard_normal_variate():
     # Act & Assert
     check_estimator(transformer)
 
+
+# RangeCut
+def test_compliance_range_cut():
+    # Arrange
+    transformer = RangeCut()
+    # Act & Assert
+    check_estimator(transformer)
+
+
+# RobustNormalVariate
+def test_compliance_robust_normal_variate():
+    # Arrange
+    transformer = RobustNormalVariate()
+    # Act & Assert
+    check_estimator(transformer)
+
 # SubtractReference
 def test_compliance_subtract_reference():
     # Arrange
@@ -114,6 +202,7 @@ def test_compliance_subtract_reference():
     # Act & Assert
     check_estimator(transformer)
 
+
 # WhittakerSmooth
 def test_compliance_whittaker_smooth():
     # Arrange
